# Function reference {.doc .doc-index}

## Some section

Some description...


| | |
| --- | --- |
| [functionname](functionname.qmd#vscodenb.modulename.functionname) | The sum of two numbers. |

## Some other section

Some description...


| | |
| --- | --- |
| [scriptname](scriptname.qmd#vscodenb.modulename.scriptname) |  |